@@ -1,4 +1,4 @@
-from time import perf_counter
+from time import sleep, perf_counter
 from botocore.exceptions import WaiterError
 from botocore.waiter import WaiterModel
 from botocore.waiter import create_waiter_with_client
@@ -93,34 +93,34 @@ class DBClusterWaiter:
                                 "argument": f"DBClusters[?DBClusterIdentifier=='{self.cluster_identifier}'].Status | [0] == 'backing-up'",
                             },
                             {
-                                "expected": "deleted",
-                                "matcher": "pathAny",
+                                "expected": True,
+                                "matcher": "path",
                                 "state": "failure",
-                                "argument": "DBClusters[].Status",
+                                "argument": f"DBClusters[?DBClusterIdentifier=='{self.cluster_identifier}'].Status | [0] == 'deleted'",
                             },
                             {
-                                "expected": "deleting",
-                                "matcher": "pathAny",
+                                "expected": True,
+                                "matcher": "path",
                                 "state": "failure",
-                                "argument": "DBClusters[].Status",
+                                "argument": f"DBClusters[?DBClusterIdentifier=='{self.cluster_identifier}'].Status | [0] == 'deleting'",
                             },
                             {
-                                "expected": "failed",
-                                "matcher": "pathAny",
+                                "expected": True,
+                                "matcher": "path",
                                 "state": "failure",
-                                "argument": "DBClusters[].Status",
+                                "argument": f"DBClusters[?DBClusterIdentifier=='{self.cluster_identifier}'].Status | [0] == 'failed'",
                             },
                             {
-                                "expected": "inaccessible-encryption-credentials",
-                                "matcher": "pathAny",
+                                "expected": True,
+                                "matcher": "path",
                                 "state": "failure",
-                                "argument": "DBClusters[].Status",
+                                "argument": f"DBClusters[?DBClusterIdentifier=='{self.cluster_identifier}'].Status | [0] == 'inaccessible-encryption-credentials'",
                             },
                             {
-                                "expected": "stopped",
-                                "matcher": "pathAny",
+                                "expected": True,
+                                "matcher": "path",
                                 "state": "failure",
-                                "argument": "DBClusters[].Status",
+                                "argument": f"DBClusters[?DBClusterIdentifier=='{self.cluster_identifier}'].Status | [0] == 'stopped'",
                             },
                         ],
                     }
@@ -150,34 +150,34 @@ class DBClusterWaiter:
                                 "argument": f"DBClusters[?DBClusterIdentifier=='{self.cluster_identifier}'].Status | [0] == 'resetting-master-credentials'",
                             },
                             {
-                                "expected": "deleted",
-                                "matcher": "pathAny",
+                                "expected": True,
+                                "matcher": "path",
                                 "state": "failure",
-                                "argument": "DBClusters[].Status",
+                                "argument": f"DBClusters[?DBClusterIdentifier=='{self.cluster_identifier}'].Status | [0] == 'deleted'",
                             },
                             {
-                                "expected": "deleting",
-                                "matcher": "pathAny",
+                                "expected": True,
+                                "matcher": "path",
                                 "state": "failure",
-                                "argument": "DBClusters[].Status",
+                                "argument": f"DBClusters[?DBClusterIdentifier=='{self.cluster_identifier}'].Status | [0] == 'deleting'",
                             },
                             {
-                                "expected": "failed",
-                                "matcher": "pathAny",
+                                "expected": True,
+                                "matcher": "path",
                                 "state": "failure",
-                                "argument": "DBClusters[].Status",
+                                "argument": f"DBClusters[?DBClusterIdentifier=='{self.cluster_identifier}'].Status | [0] == 'failed'",
                             },
                             {
-                                "expected": "inaccessible-encryption-credentials",
-                                "matcher": "pathAny",
+                                "expected": True,
+                                "matcher": "path",
                                 "state": "failure",
-                                "argument": "DBClusters[].Status",
+                                "argument": f"DBClusters[?DBClusterIdentifier=='{self.cluster_identifier}'].Status | [0] == 'inaccessible-encryption-credentials'",
                             },
                             {
-                                "expected": "stopped",
-                                "matcher": "pathAny",
+                                "expected": True,
+                                "matcher": "path",
                                 "state": "failure",
-                                "argument": "DBClusters[].Status",
+                                "argument": f"DBClusters[?DBClusterIdentifier=='{self.cluster_identifier}'].Status | [0] == 'stopped'",
                             },
                         ],
                     }
@@ -207,39 +207,22 @@ class DBClusterWaiter:
                                 "argument": f"DBClusters[?DBClusterIdentifier=='{self.cluster_identifier}'].Status | [0] == 'deleting'",
                             },
                             {
-                                "expected": "DBClusterNotFound",
-                                "matcher": "error",
-                                "state": "success",
-                            },
-                            {
-                                "expected": "deleting",
-                                "matcher": "pathAny",
-                                "state": "retry",
-                                "argument": "DBClusters[].Status",
-                            },
-                            {
-                                "expected": "creating",
-                                "matcher": "pathAny",
+                                "expected": True,
+                                "matcher": "path",
                                 "state": "failure",
-                                "argument": "DBClusters[].Status",
+                                "argument": f"DBClusters[?DBClusterIdentifier=='{self.cluster_identifier}'].Status | [0] == 'modifying'",
                             },
                             {
-                                "expected": "modifying",
-                                "matcher": "pathAny",
+                                "expected": True,
+                                "matcher": "path",
                                 "state": "failure",
-                                "argument": "DBClusters[].Status",
+                                "argument": f"DBClusters[?DBClusterIdentifier=='{self.cluster_identifier}'].Status | [0] == 'rebooting'",
                             },
                             {
-                                "expected": "rebooting",
-                                "matcher": "pathAny",
+                                "expected": True,
+                                "matcher": "path",
                                 "state": "failure",
-                                "argument": "DBClusters[].Status",
-                            },
-                            {
-                                "expected": "resetting-master-credentials",
-                                "matcher": "pathAny",
-                                "state": "failure",
-                                "argument": "DBClusters[].Status",
+                                "argument": f"DBClusters[?DBClusterIdentifier=='{self.cluster_identifier}'].Status | [0] == 'resetting-master-credentials'",
                             },
                         ],
                     }
@@ -288,6 +271,7 @@ class DBClusterWaiter:
                 f"Waiting for cluster {db_cluster_identifier} to become available"
             )
             tic = perf_counter()
+            sleep(5)
             self.running.wait()
         except WaiterError as e:
             raise Exception(e)
@@ -319,6 +303,7 @@ class DBClusterWaiter:
             # the command to propagate through AWS :sadparrot:
             # Using the extra wait stage here we avoid magic variables :pray:
             tic = perf_counter()
+            sleep(5)
             self.modifying_start.wait()
             toc = perf_counter()
             self.logger.warning(
@@ -328,6 +313,7 @@ class DBClusterWaiter:
             self.logger.warning(
                 f"Waiting for cluster {db_cluster_identifier} to become available"
             )
+            sleep(5)
             self.modifying_stop.wait()
         except WaiterError as e:
             raise Exception(e)
@@ -375,6 +361,7 @@ class DBClusterWaiter:
             )
 
         if wait:
+            sleep(5)
             try:
                 self.logger.warning(
                     f"Waiting for cluster {db_cluster_identifier} to be deleted"
@@ -557,6 +544,7 @@ class DBInstanceWaiter:
                 f"Waiting for cluster instance {db_instance_identifier} to become available"
             )
             tic = perf_counter()
+            sleep(5)
             self.running.wait()
         except WaiterError as e:
             raise Exception(e)
@@ -605,6 +593,7 @@ class DBInstanceWaiter:
                     f"Waiting for cluster instance {db_instance_identifier} to be deleted"
                 )
                 tic = perf_counter()
+                sleep(5)
                 self.stopped.wait()
             except WaiterError as e:
                 raise Exception(e)
